@@ -3,7 +3,7 @@
 summary.gdm <- function( object , ... ){
     # object      ... object from rasch.mml                #
     cat("-----------------------------------------------------------------------------\n")
-    d1 <- packageDescription("CDM")
+    d1 <- utils::packageDescription("CDM")
 	cat( paste( d1$Package , " " , d1$Version , " (" , d1$Date , ")" , sep="") , "\n\n" )	
 	cat( "Date of Analysis:" , paste( object$time$s2 ) , "\n" )
 	cat("Computation Time:" , print(object$time$s2 - object$time$s1), "\n\n")
