@@ -10,7 +10,7 @@ summary.mcdina <- function( object , rdigits = 4 , ... ){
 	#-------------------------------------------------------
 	# Parameter summary
 	cat("----------------------------------------------------------------------------\n")
-	d1 <- packageDescription("CDM")
+	d1 <- utils::packageDescription("CDM")
 	cat( paste( d1$Package , " " , d1$Version , " (" , d1$Date , ")" , sep="") , "\n" )	
 	cat( "Date of Analysis:" , paste( object$time$s2 ) , "\n" )
 	cat("Computation Time:" , print(object$time$s2 - object$time$s1), "\n\n")	
